module MolecularDynamicsFiles

using LinearAlgebra
using Printf
using StaticArrays
using DataFrames
using CSV
using GZip
using EnumX
using DocStringExtensions

export MDFrame
export timestep
export id_tags
export elements
export masses
export particle_types
export mol_tags
export positions
export scaled_positions
export unwrapped_positions
export scaled_unwrapped_positions
export velocities
export velocities_x
export velocities_y
export velocities_z
export images
export boxvectors
export boxorigin
export extra_scalars
export add_extra_scalar!
export system_properties
export box

export SimulationBox
export BoundaryConditions
export basis
export origin
export pbc
export bc
export istriclinic

export ReadTrajectory
export WriteTrajectory
export done

export Format
export BoundaryCondition

include("formats.jl")

include("mdfilestream.jl")
include("table.jl")
include("fileparsingerror.jl")

include("simulationbox.jl")
include("mdframe.jl")
include("readtrajectory.jl")
include("writetrajectory.jl")

include("formats/readlammpsdump.jl")
include("formats/writelammpsdump.jl")
include("formats/readlammpsdata.jl")
include("formats/readcfg.jl")
include("formats/readxyz.jl")

end # module MolecularDynamicsFiles
