function readnextframe(s::MDFileStream, ::Val{Format.XYZ}, fmasktimestep::Int)::MDFrame
    check_eof(s)

    natoms = 0
    comment = ""
    particles = DataFrame()

    try
        natoms = try
            mark(s)
            parse(Int, readline(s))
        catch
            reset(s)
            rethrow()
        end

        comment = readline(s)

        particles = readparticlesxyz(s, natoms)
    catch(ex)
        if typeof(ex) === FileParsingError
            rethrow()
        end
        # wrap errors in FileParsingError
        throw(FileParsingError(s, sprint(showerror, ex)))
    end

    lo = SVector{3,Float64}(min(particles.x...), min(particles.y...), min(particles.z...))
    hi = SVector{3,Float64}(max(particles.x...), max(particles.y...), max(particles.z...))

    basis = SMatrix{3,3,Float64}([(hi-lo)[1] 0 0; 0 (hi-lo)[2] 0; 0 0 (hi-lo)[3]])
    origin = lo
    
    f = BoundaryCondition.Fixed
    bc = BoundaryConditions(f,f,f,f,f,f)
    box = SimulationBox(basis, origin, bc, false)

    system_properties = Dict{Symbol,Any}()

    MDFrame(fmasktimestep, box, particles, system_properties)
end

function readparticlesxyz(s::MDFileStream, natoms::Int)::DataFrame
    tableheader = ["element", "x", "y", "z"]
    tabletypes = [String, Float64, Float64, Float64]

    readtable(s; rows=natoms, header=tableheader, types=tabletypes)
end