@testset "Read LAMMPS Data" begin

@testset "Simple LAMMPS Data frame (atomic style)" begin
    traj = ReadTrajectory("./data/simpleframe.data", Format.LAMMPSData)
    frame = read(traj)

    @test timestep(frame) == 20
    @test system_properties(frame)[:units] == "lj"

    @test isapprox(boxorigin(frame), [-0.5, -5.3, -10.93])
    @test isapprox(boxvectors(frame), [1 0 0; 0.001 10.6 0.0; 0.002 0.003 31.03])
    @test pbc(frame) == (true, true, true)
    @test istriclinic(frame)

    @test id_tags(frame) == 1:3
    @test particle_types(frame) == [1, 2, 2]

    @test isapprox(frame.particles.x, [0, -0.23, -0.2])
    @test isapprox(frame.particles.y, [0, 5, 2.3])
    @test isapprox(frame.particles.z, [0, -5, 20])
    
    @test isapprox(frame.particles.mass, [12, 1, 1])
    @test isapprox(frame.particles.vx, [0, 1, -5.2])
    @test isapprox(frame.particles.vy, [0, 2, 20.4])
    @test isapprox(frame.particles.vz, [0, 3, 20.3])
end

end # testset Read LAMMPS Data