@testset "Read CFG" begin

@testset "SiVacancy.cfg" begin
    traj = ReadTrajectory("./data/SiVacancy.cfg", Format.CFG)
    frame = read(traj)

    @test timestep(frame) == 0
    @test length(frame) == 1727
    @test system_properties(frame)[:R] == 1.0
    @test system_properties(frame)[:A] == 1.0

    @test isapprox(boxorigin(frame), [0, 0, 0])
    @test isapprox(boxvectors(frame), [32.58569867 8.6469e-16 8.6469e-16; 0 32.58569867 8.6369e-16; 0 0 32.58569867])
    @test pbc(frame) == (true, true, true)
    @test istriclinic(frame)

    m = masses(frame)
    pos = scaled_positions(frame)
    vel = velocities(frame)
    elts = elements(frame)

    @test unique(elts) == ["Si"]
    @test unique(m) == [28.0855]

    @test isapprox(pos[1], [0.0208333333333333, 0.0208333333333333, 0.0208333333333333])
    @test isapprox(vel[1], [0, 0, 0])

    
    @test isapprox(pos[1241], [0.729166666666667, 0.229166666666667, 0.895833333333333])
    @test isapprox(vel[1241], [4.3, 5.4, 0.2])

    @test isapprox(pos[1727], [0.979166666666667, 0.979166666666667, 0.895833333333333])
    @test isapprox(vel[1727], [0, 0, 0])
end

@testset "BubbleRaftBefore.cfg" begin
    traj = ReadTrajectory("./data/BubbleRaftBefore.cfg", Format.CFG)
    frame = read(traj)

    @test timestep(frame) == 0
    @test length(frame) == 16200
    @test system_properties(frame)[:R] == 1.0
    @test isapprox(system_properties(frame)[:A], 4.37576470588235)

    @test isapprox(boxorigin(frame), [0, 0, 0])
    @test isapprox(boxvectors(frame), [127.5 0 0; 0 119.501132067411 0; 0 0 3])
    @test pbc(frame) == (true, true, true)
    @test !istriclinic(frame)
    
    extra = extra_scalars(frame)
    @test keys(extra) == Set([:kine, :pote, :s11, :s22, :s12, :hydro, :mises, :Lmin])
    
    m = masses(frame)
    pos = scaled_positions(frame)

    # no velocity data
    @test_throws Exception velocities(frame)

    elts = elements(frame)

    @test elts == append!(fill("Ar", 7351), fill("C", 8849))
    @test m == append!(fill(1.0, 7351), fill(12.0, 8849))

    @test isapprox(pos[1], [0.0016667, 0.00616, 0.5])
    @test isapprox(extra[:kine][1], 0)
    @test isapprox(extra[:pote][1], -2)
    @test isapprox(extra[:s11][1], -1.9431e-13)
    @test isapprox(extra[:s22][1], -2.9917e-13)
    @test isapprox(extra[:s12][1], 1.6811e-13)
    @test isapprox(extra[:hydro][1], -2.4674e-13)
    @test isapprox(extra[:mises][1], 1.7609e-13)
    @test isapprox(extra[:Lmin][1], 98.648)

    @test isapprox(pos[2777], [0.25406, 0.11493, 0.5])
    @test isapprox(extra[:kine][2777], 0.0086879)
    @test isapprox(extra[:pote][2777], -2.9196)
    @test isapprox(extra[:s11][2777], 2.369)
    @test isapprox(extra[:s22][2777], 6.8575)
    @test isapprox(extra[:s12][2777], 1.5999)
    @test isapprox(extra[:hydro][2777], 4.6133)
    @test isapprox(extra[:mises][2777], 2.7562)
    @test isapprox(extra[:Lmin][2777], 98.95)

    @test isapprox(pos[16200], [0.99833, 0.66279, 0.5])
    @test isapprox(extra[:kine][16200], 0.011466)
    @test isapprox(extra[:pote][16200], -1.9761)
    @test isapprox(extra[:s11][16200], -2.7074)
    @test isapprox(extra[:s22][16200], -0.026619)
    @test isapprox(extra[:s12][16200], -0.0010034)
    @test isapprox(extra[:hydro][16200], -1.367)
    @test isapprox(extra[:mises][16200], 1.3404)
    @test isapprox(extra[:Lmin][16200], 98.648)
end

end # testset Read CFG